CHAR_LIB = "".join([chr(i + 32) for i in range(93)]) + "".join([chr(i + 161) for i in range(95)]) + "".join([chr(i + 1000) for i in range(110)])

WILL_BE_STRIPPED = False
